
if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_PluginMenu' ) )
	if not Exists ( Select * From INFORMATION_SCHEMA.Columns Where TABLE_NAME like 'A_PluginMenu' 
								and TABLE_SCHEMA like 'dbo'
								and COLUMN_NAME like 'HelpLink' )
	Alter Table dbo.A_PluginMenu
	Add HelpLink nvarchar ( 500 )
GO

if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_PluginMenu' ) )
	Update A_PluginMenu
	Set HelpLink = ''
	Where HelpLink is Null
GO


if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_PluginMenu_GetViewed' ) )
	Drop Procedure dbo.A_PluginMenu_GetViewed
GO

Create procedure dbo.A_PluginMenu_GetViewed
	@iduser uniqueidentifier
as
begin

	Select * 
	From (
	
		Select pm.Id, pm.OrderIndex, pm.IdModule, pm.IdForm, 
			pm.HeaderText, pm.MenuText, pm.VisibleAllDefault, pm.Description,
			pm.Type, pm.AddressString, pm.Enabled, pm.HelpLink
		From A_PluginMenu pm 
			Inner join A_PluginMenu_User u 
				on ( u.IdMenuLink = pm.Id )
				and ( u.IdUser = @iduser )
				and ( u.Visible = 1 )
		Where pm.VisibleAllDefault = 0

		Union all

		Select pm.Id, pm.OrderIndex, pm.IdModule, pm.IdForm, 
			pm.HeaderText, pm.MenuText, pm.VisibleAllDefault, pm.Description,
			pm.Type, pm.AddressString, pm.Enabled, pm.HelpLink
		From A_PluginMenu pm 
		Where pm.VisibleAllDefault = 1
			And not exists ( 	
					Select IdMenuLink 
					From A_PluginMenu_User u 
					Where ( u.IdMenuLink = pm.Id ) 
						And ( u.IdUser = @iduser )
						And ( u.Visible = 0 )
					)
	)a
	Order By OrderIndex
end
GO


if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_PluginMenu_GetAll' ) )
	Drop Procedure dbo.A_PluginMenu_GetAll
GO

Create procedure dbo.A_PluginMenu_GetAll
as
begin
	Select Id, OrderIndex, IdModule, IdForm, 
		HeaderText, MenuText, VisibleAllDefault, Description,
		Type, AddressString, Enabled, HelpLink
	From A_PluginMenu
	Order by OrderIndex
end
GO

if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_PluginMenu_Save' ) )
	Drop Procedure dbo.A_PluginMenu_Save
GO

Create procedure dbo.A_PluginMenu_Save
	@id uniqueidentifier, 
	@orderindex int, 
	@idmodule uniqueidentifier, 
	@idform uniqueidentifier, 
	@headertext nvarchar ( 300 ),  
	@menutext nvarchar ( 300 ), 
	@visiblealldefault bit, 
	@description ntext,
	@type int, 
	@addressstring nvarchar ( 3000 ),
	@enabled bit,
	@helplink nvarchar ( 500 ) = ''
as
begin
	Declare @oldorder int
	set @oldorder = -1

	--    
	Select @oldorder = OrderIndex 
	From A_PluginMenu
	Where Id = @id

	--    
	if ( @@rowcount > 0 )
	begin
		-- 
		Delete From A_PluginMenu
		Where Id = @id

		--   
		if ( @oldorder != @orderindex )		
			Update A_PluginMenu
			Set OrderIndex = OrderIndex - 1
			Where OrderIndex > @oldorder
	end

	--   
	if ( @oldorder != @orderindex )		
		Update A_PluginMenu
		Set OrderIndex = OrderIndex + 1
		Where OrderIndex >= @orderindex

	--    
	Insert 
	Into A_PluginMenu ( Id, OrderIndex, IdModule, IdForm, HeaderText, MenuText, VisibleAllDefault, Description, Type, 

AddressString, Enabled, HelpLink )
	Values ( @id, @orderindex, @idmodule, @idform, @headertext, @menutext, @visiblealldefault, @description, @type, 

@addressstring, @enabled, @helplink )
end
GO



