if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_CardUserResultsProject'))
	drop table dbo.A_TaskManager_CardUserResultsProject
GO


CREATE TABLE [A_TaskManager_CardUserResultsProject] 
(	
	Id int NOT NULL,
	Name nvarchar (200),
	IsOutput bit NOT NULL ,
	Success bit NOT NULL ,
	IsDefault bit NOT NULL ,
	ProjectId uniqueidentifier NOT NULL,

) ON [PRIMARY]
GO


if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_UserResultsProject_GetForModify'))
	drop procedure dbo.A_TaskManager_UserResultsProject_GetForModify
GO

Create procedure dbo.A_TaskManager_UserResultsProject_GetForModify
	@idproject uniqueidentifier
as
begin
	Select *
	FROM A_TaskManager_CardUserResultsProject 
	Where ProjectId = @idproject
end
GO



if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_UserResultsProject_Clear'))
	drop procedure dbo.A_TaskManager_UserResultsProject_Clear
GO

Create procedure dbo.A_TaskManager_UserResultsProject_Clear
	@idproject uniqueidentifier
as
begin
	Delete
	FROM A_TaskManager_CardUserResultsProject 
	Where ProjectId = @idproject
end
GO



if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_UserResultsProject_Save'))
	drop procedure dbo.A_TaskManager_UserResultsProject_Save
GO

Create procedure dbo.A_TaskManager_UserResultsProject_Save
	@id int,	
	@name nvarchar ( 200 ),
	@isoutput bit,
	@success bit,
	@isdefault bit,
	@idproject uniqueidentifier
as
begin
	Insert into A_TaskManager_CardUserResultsProject
	( Id, Name, IsOutput, Success, IsDefault, ProjectId )
	Values
	( @id, @name, @isoutput, @success, @isdefault, @idproject )
end
GO


if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_TaskManager_Projects' ) )
	if not Exists ( Select * From INFORMATION_SCHEMA.Columns Where TABLE_NAME like 'A_TaskManager_Projects' 
								and TABLE_SCHEMA like 'dbo'
								and COLUMN_NAME like 'UserResType' )
	Alter Table dbo.A_TaskManager_Projects
	Add UserResType int
GO


if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_TaskManager_Projects' ) )
	Update A_TaskManager_Projects
	Set UserResType = 0
	Where UserResType is Null
GO



if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_Project_Save'))
	drop procedure dbo.A_TaskManager_Project_Save
GO

Create procedure dbo.A_TaskManager_Project_Save
	@id 	uniqueidentifier,
	@name 	nvarchar ( 100 ),
	@description nvarchar ( 255 ) = '',
	@datecreation DateTime,
	@idcreator uniqueidentifier,
	@mainscript nvarchar ( 500 ) = null,
	@shared bit = 1,
	@urestype int = 0
as
begin

	Update A_TaskManager_Projects
	Set	Name = @name,
		Description = @description,
		Shared = @shared,
		UserResType = @urestype
	Where Id = @id
	

	if ( @@rowcount = 0 )
		Insert into A_TaskManager_Projects ( Id, Name, Description, DateCreation, IdCreator, MainScript, Shared, UserResType )
		Values ( @id, @name, @description, @datecreation, @idcreator, @mainscript, @shared, @urestype )

	--      
	If Exists ( Select * FROM Master..sysdatabases where name like 'oktell_cc_temp' )
	If Exists ( Select * FROM oktell_cc_temp..sysobjects where id = Object_Id ( 'oktell_cc_temp.dbo.A_Cube_CC_Cat_Project' ) )
		Update oktell_cc_temp.dbo.A_Cube_CC_Cat_Project
		Set Name = @name
		Where Id = @id
end
GO


if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_Project_GetAllViewed'))
	drop procedure dbo.A_TaskManager_Project_GetAllViewed
GO

Create procedure dbo.A_TaskManager_Project_GetAllViewed
	@iduser uniqueidentifier
as
begin
	Declare @tpus table ( IdProject uniqueidentifier )

	Insert into @tpus (IdProject)
		Select distinct ( IdProject )
		From A_TaskManager_ProjectUsers
		Where IdUser = @iduser
	Insert into @tpus
		Select Id
		From A_TaskManager_Projects p
		Where Shared = 1 
			and not exists ( Select IdProject From @tpus Where IdProject = p.Id )

	Select tp.Id, tp.Name, tp.Description, tp.DateCreation, tp.IdCreator, tp.MainScript, tp.Shared, tp.UserResType
	From A_TaskManager_Projects tp
		Inner join @tpus filter on tp.Id = filter.IdProject
end
GO



if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_Project_GetAll'))
	drop procedure dbo.A_TaskManager_Project_GetAll
GO

Create procedure [dbo].A_TaskManager_Project_GetAll
as
begin
	Select Id, Name, Description, DateCreation, IdCreator, MainScript, Shared, UserResType
	From A_TaskManager_Projects
end
GO




if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_TaskManager_Project_Delete' ))
	Drop procedure dbo.A_TaskManager_Project_Delete
GO

Create procedure [dbo].A_TaskManager_Project_Delete
	@id 	uniqueidentifier	
as
begin

	--  
	Delete from A_TaskManager_Projects
	Where Id = @id

	--  
	DECLARE tcursor CURSOR FOR 
		select id 
		from A_TaskManager_Lists
		where ProjectId = @id 

	declare @idlist uniqueidentifier

	OPEN tcursor
	FETCH NEXT FROM tcursor INTO @idlist

	WHILE @@FETCH_STATUS = 0
	BEGIN

	exec A_TaskManager_List_Delete @idlist


	FETCH NEXT FROM tcursor INTO @idlist
	END

	CLOSE tcursor
	DEALLOCATE tcursor

	--  ,     
	Delete From A_TaskManager_Tasks 
	Where IdProject = @id

	--       
	--exec A_TaskManager_UserResultsProject_Clear @id

end
GO


if exists (select * from dbo.sysobjects where id = object_id('dbo.A_TaskManager_UserResultsProject_GetForChoice'))
	drop procedure dbo.A_TaskManager_UserResultsProject_GetForChoice
GO

Create procedure dbo.A_TaskManager_UserResultsProject_GetForChoice
	@idproject uniqueidentifier
as
begin
	Declare @type int

	Select @type = UserResType 
	From A_TaskManager_Projects 
	Where Id = @idproject

	if ( @type = 0 )
		Select Id, Name, IsOutput, Success, IsDefault
		FROM A_TaskManager_CardUserResults
 	else if ( @type = 1 )
		Select Id, Name, IsOutput, Success, IsDefault
		FROM A_TaskManager_CardUserResultsProject
	else 
	begin	
		Declare @tmp table ( Id int, Name nvarchar ( 200 ), IsOutput bit, Success bit, IsDefault bit )
		
		Insert into @tmp 
			Select Id, Name, IsOutput, Success, IsDefault
			FROM A_TaskManager_CardUserResultsProject

		Insert into @tmp
			Select Id, Name, IsOutput, Success, IsDefault
			FROM A_TaskManager_CardUserResults r
			Where not exists ( Select Id From @tmp Where Id = r.Id )

		Select * 
		From @tmp		
		Where Name != ''
	end
end
GO